netapp_ontap.models.volume_space_logical_space API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_space_logical_space`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeSpaceLogicalSpaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeSpaceLogicalSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET`

    The amount of space available in this volume with storage efficiency space considered used, in bytes.

  `enforcement GET POST PATCH`

    Specifies whether space accounting for operations on the volume is done along with storage efficiency.

  `reporting GET POST PATCH`

    Specifies whether space reporting on the volume is done along with storage efficiency.

  `used_by_afs GET`

    The virtual space used by AFS alone (includes volume reserves) and along with storage efficiency, in bytes.